
// *****************
// Timer / Counter 0
// *****************







// *****************
// Timer / Counter 1
// *****************



procedure TIMER1_aus;
begin
  TCCR1A:=%00000000;
  TCCR1B:=%00000000;
  TIMSK1:=%00000000;
end TIMER1_aus;





procedure Init_TIMER1_COMPA(Wert : Word);
VAR
  B_wert_L : Byte;
  B_Wert_H : Byte;
begin
{
; CTC Modus (Clear Timer on Compare Match mode)
; ---------------------------------------------

; genutzt wird der 16-Bit Timer1

; TCCR1B = Timer/Counter control Register B des Timers1
; | ICNC1 | ICES1 | leer | WGM13 | WGM12 | CS12 | CS11 | CS10 |
; CS12  CS11  CS10
;   0     0     1  = CPU-Takt ohne Teiler
;
; WGM12 = // CTC-Modus, TOP = OCR1A
;
; Timer 1, ein 16-Bit-Timer, wird mit einem Vorteiler von 1 betrieben.
; Dadurch wird erreicht, dass der Timer mit höchster Zeitauflösung arbeiten kann.
; Bei jedem Ticken des Systemtaktes von 4 MHz wird auch der Timer um 1 erhöht.
; Zusätzlich wird noch das WGM12-Bit bei der Konfiguration gesetzt.
; Dadurch wird der Timer in den CTC-Modus gesetzt.
; Dabei wird der Inhalt des Timers hardwaremäßig mit dem Inhalt des OCR1A-Registers verglichen.
; Stimmen beide überein, so wird der Timer auf 0 zurückgesetzt und im nächsten Taktzyklus ein OCIE1A-Interrupt ausgelöst.
; Dadurch ist es möglich, exakt die Anzahl an Taktzyklen festzulegen, die von einem Interrupt zum nächsten vergehen sollen.
}

  // Bit 7:6 – COM1A1:0: Compare Output Mode for channel A
  // Bit 5:4 – COM1B1:0: Compare Output Mode for channel B
  // Normal port operation, OC1A/OC1B disconnected.
  // 0 0 0 0

//  TCCR1A:=%00000000;


  // Timer/Counter Control Register 0
  // Bit 4:3 – WGM13:2: Waveform Generation Mode
  //   0 1 - CTC - OCR1A
//  TCCR1B:=%00001000;    // kein Takt (Timer/Zaehler ist gestoppt)
  TCCR1B:=%00001001;    // kein Vorteiler
//  TCCR1B:=%00001010;    // Vorteiler = Takt/8
//  TCCR1B:=%00001011;    // Vorteiler = Takt/64
//  TCCR1B:=%00001100;    // Vorteiler = Takt/256
//  TCCR1B:=%00001101;    // Vorteiler = Takt/1024
//  TCCR1B:=%00001110;    // Externe Taktquelle an T0 Pin. Takt an der fallenden Flanke
//  TCCR1B:=%00001111;    // Externe Taktquelle an T0 Pin. Takt an der steigenden Flanke

{
; Einstellen der Interrupt-Zeit
}
  B_Wert_H:=High(Wert);
  B_Wert_L:=Low(Wert);

  OCR1AH:=B_Wert_H;
  OCR1AL:=B_Wert_L;

{
; TIMSK
; | TICIE1 | OCIE1A | OCIE1B | TOIE1 |
;
; TICIE1 - Timer 1 Input Capture Interrupt Enable
; OCIE1A - Timer 1 Output Compare A Match Interrupt Enable
; OCIE1B - Timer 1 Output Compare B Match Interrupt Enable
; TOIE1  - Timer 1 Overflow Interrupt Enable
;
; OCIE1A - Timer/Counter 1 Vergleichszahl A Interrupt - 1: Int bei Erreichen Stand in A
;
}
  // Timer/Counter Interrupt Mask Register
  // Bit 1 – OCIE1A: Timer/Counter1, Output Compare A Match Interrupt Enable
 // OCIE1A=1 -> Interrupt bei Output Compare A

  TIMSK1:=%00000010;

end Init_TIMER1_COMPA;






// *****************
// Timer / Counter 2
// *****************




procedure Init_TIMER2_OVF;
begin

  TCCR2A:=%00000000;

  // Timer/Counter Control Register 0
//  TCCR2B:=%00000000;    // kei  Takt (Timer/Zaehler ist gestoppt)
//  TCCR2B:=%00000001;    // kein Vorteiler
//  TCCR2B:=%00000010;    // Vorteiler = Takt/8
//  TCCR2B:=%00000011;    // Vorteiler = Takt/64
//  TCCR2B:=%00000100;    // Vorteiler = Takt/256
  TCCR2B:=%00000101;    // Vorteiler = Takt/1024
//  TCCR2B:=%00000110;    // Externe Taktquelle an T0 Pin. Takt an der fallenden Flanke
//  TCCR2B:=%00000111;    // Externe Taktquelle an T0 Pin. Takt an der steigenden Flanke

  ASSR:=%00000000;

  // Timer/Counter Interrupt Mask Register
  // Bit 0 – TOIE2: Timer/Counter2 Overflow Interrupt Enable
  TIMSK2:=%00000001;    // TOIE2=1 -> Interrupt bei Overflow
end Init_TIMER2_OVF;






